@@ -132,7 +132,7 @@ void PixmapView::PreviewCal(const QString& ImagePath, const QString& /*tmpPath*/
 
     *m_PreviewProc << ImagePath;
     *m_PreviewProc << m_previewFileName;
-    m_previewOutput.append(" -verbose " + ImagePath + " " + m_previewFileName + "\n\n");
+    m_previewOutput.append(" -verbose " + ImagePath + ' ' + m_previewFileName + "\n\n");
 
     connect(m_PreviewProc, SIGNAL(finished(int, QProcess::ExitStatus)),
             this, SLOT(slotPreviewProcessFinished()));
