@@ -20,6 +20,9 @@
  *
  * ============================================================ */
 
+#include "plugin_batchprocessimages.h"
+#include "plugin_batchprocessimages.moc"
+
 // C ANSI includes
 
 extern "C"
@@ -64,17 +67,15 @@ extern "C"
 #include "renameimagesdialog.h"
 #include "resizeimagesdialog.h"
 
-#include "plugin_batchprocessimages.h"
-#include "plugin_batchprocessimages.moc"
 
 K_PLUGIN_FACTORY(BatchProcessImagesFactory, registerPlugin<Plugin_BatchProcessImages>();)
 K_EXPORT_PLUGIN(BatchProcessImagesFactory("kipiplugin_batchprocessimages"))
 
 Plugin_BatchProcessImages::Plugin_BatchProcessImages(QObject *parent, const QVariantList&)
-        : KIPI::Plugin(BatchProcessImagesFactory::componentData(),
-                       parent, "BatchProcessImages")
+                         : KIPI::Plugin(BatchProcessImagesFactory::componentData(),
+                                        parent, "BatchProcessImages")
 {
-    kDebug(51001) << "Plugin_BatchProcessImages plugin loaded" ;
+    kDebug(AREA_CODE_LOADING) << "Plugin_BatchProcessImages plugin loaded" ;
 }
 
 void Plugin_BatchProcessImages::setup(QWidget* widget)
@@ -124,8 +125,9 @@ void Plugin_BatchProcessImages::setup(QWidget* widget)
 
     KIPI::Interface* interface = dynamic_cast< KIPI::Interface* >(parent());
 
-    if (!interface) {
-        kError(51000) << "Kipi interface is null!" ;
+    if (!interface)
+    {
+        kError() << "Kipi interface is null!" ;
         return;
     }
 
@@ -174,8 +176,9 @@ void Plugin_BatchProcessImages::slotActivate()
 {
     KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>(parent());
 
-    if (!interface) {
-        kError(51000) << "Kipi interface is null!" ;
+    if (!interface)
+    {
+        kError() << "Kipi interface is null!" ;
         return;
     }
 
@@ -190,7 +193,8 @@ void Plugin_BatchProcessImages::slotActivate()
     if (!images.isValid())
         return;
 
-    if (images.images().isEmpty()) {
+    if (images.images().isEmpty())
+    {
         KMessageBox::sorry(kapp->activeWindow(),
                            i18n("Please select an album or a selection of images."));
         return;
@@ -198,7 +202,7 @@ void Plugin_BatchProcessImages::slotActivate()
 
     KUrl::List urlList = images.images();
 
-    QString from(sender()->name());
+    QString from(sender()->objectName());
 
     if (from == "batch_convert_images")
     {
@@ -251,7 +255,7 @@ void Plugin_BatchProcessImages::slotActivate()
     }
     else
     {
-        kWarning(51000) << "The impossible happened... unknown batch action specified";
+        kWarning() << "The impossible happened... unknown batch action specified";
         return;
     }
 }
@@ -275,6 +279,6 @@ KIPI::Category Plugin_BatchProcessImages::category(KAction* action) const
     else if (action == m_action_resizeimages)
         return KIPI::BatchPlugin;
 
-    kWarning(51000) << "Unrecognized action for plugin category identification" ;
+    kWarning() << "Unrecognized action for plugin category identification";
     return KIPI::BatchPlugin; // no warning from compiler, please
 }
