@@ -39,6 +39,14 @@
     ADOBE DNG CONVERTER: ftp://ftp.adobe.com/pub/adobe/photoshop/cameraraw/win/4.x
 */
 
+// C ansi includes
+
+extern "C"
+{
+#include <sys/stat.h>
+#include <utime.h>
+}
+
 // Qt includes
 
 #include <QImage>
@@ -99,6 +107,16 @@ bool DNGWriter::compressLossLess() const
     return d->jpegLossLessCompression;
 }
 
+void DNGWriter::setUpdateFileDate(bool b)
+{
+    d->updateFileDate = b;
+}
+
+bool DNGWriter::updateFileDate() const
+{
+    return d->updateFileDate;
+}
+
 void DNGWriter::setBackupOriginalRawFile(bool b)
 {
     d->backupOriginalRawFile = b;
@@ -147,7 +165,7 @@ int DNGWriter::convert()
     {
         if (inputFile().isEmpty())
         {
-            kDebug(51000) << "DNGWriter: No input file to convert. Aborted..." ;
+            kDebug() << "DNGWriter: No input file to convert. Aborted..." ;
             return -1;
         }
 
@@ -165,12 +183,12 @@ int DNGWriter::convert()
 
         // -----------------------------------------------------------------------------------------
 
-        kDebug(51000) << "DNGWriter: Loading RAW data from " << inputInfo.fileName() ;
+        kDebug() << "DNGWriter: Loading RAW data from " << inputInfo.fileName() ;
 
         KDcraw rawProcessor;
         if (!rawProcessor.extractRAWData(inputFile(), rawData, identify))
         {
-            kDebug(51000) << "DNGWriter: Loading RAW data failed. Aborted..." ;
+            kDebug() << "DNGWriter: Loading RAW data failed. Aborted..." ;
             return -1;
         }
 
@@ -180,25 +198,25 @@ int DNGWriter::convert()
         int height     = identify.imageSize.height();
         int pixelRange = 16;
 
-        kDebug(51000) << "DNGWriter: Raw data loaded:" ;
-        kDebug(51000) << "--- Data Size:     " << rawData.size() << " bytes" ;
-        kDebug(51000) << "--- Date:          " << identify.dateTime.toString(Qt::ISODate) ;
-        kDebug(51000) << "--- Make:          " << identify.make ;
-        kDebug(51000) << "--- Model:         " << identify.model ;
-        kDebug(51000) << "--- Size:          " << width << "x" << height ;
-        kDebug(51000) << "--- Orientation:   " << identify.orientation ;
-        kDebug(51000) << "--- Top margin:    " << identify.topMargin ;
-        kDebug(51000) << "--- Left margin:   " << identify.leftMargin ;
-        kDebug(51000) << "--- Filter:        " << identify.filterPattern ;
-        kDebug(51000) << "--- Colors:        " << identify.rawColors ;
-        kDebug(51000) << "--- Black:         " << identify.blackPoint ;
-        kDebug(51000) << "--- White:         " << identify.whitePoint ;
-        kDebug(51000) << "--- CAM->XYZ:" ;
+        kDebug() << "DNGWriter: Raw data loaded:" ;
+        kDebug() << "--- Data Size:     " << rawData.size() << " bytes" ;
+        kDebug() << "--- Date:          " << identify.dateTime.toString(Qt::ISODate) ;
+        kDebug() << "--- Make:          " << identify.make ;
+        kDebug() << "--- Model:         " << identify.model ;
+        kDebug() << "--- Size:          " << width << "x" << height ;
+        kDebug() << "--- Orientation:   " << identify.orientation ;
+        kDebug() << "--- Top margin:    " << identify.topMargin ;
+        kDebug() << "--- Left margin:   " << identify.leftMargin ;
+        kDebug() << "--- Filter:        " << identify.filterPattern ;
+        kDebug() << "--- Colors:        " << identify.rawColors ;
+        kDebug() << "--- Black:         " << identify.blackPoint ;
+        kDebug() << "--- White:         " << identify.whitePoint ;
+        kDebug() << "--- CAM->XYZ:" ;
 
         QString matrixVal;
         for(int i=0; i<12; i+=3)
         {
-            kDebug(51000) << "                   "
+            kDebug() << "                   "
                           << QString().sprintf("%03.4f  %03.4f  %03.4f", identify.cameraXYZMatrix[0][ i ],
                                                                          identify.cameraXYZMatrix[0][i+1],
                                                                          identify.cameraXYZMatrix[0][i+2])
@@ -226,14 +244,14 @@ int DNGWriter::convert()
         }
         else
         {
-            kDebug(51000) << "DNGWriter: Bayer mosaic not supported. Aborted..." ;
+            kDebug() << "DNGWriter: Bayer mosaic not supported. Aborted..." ;
             return -1;
         }
 
         // Check if number of Raw Color components is supported.
         if (identify.rawColors != 3)
         {
-            kDebug(51000) << "DNGWriter: Number of Raw color components not supported. Aborted..." ;
+            kDebug() << "DNGWriter: Number of Raw color components not supported. Aborted..." ;
             return -1;
         }
 
@@ -245,7 +263,7 @@ int DNGWriter::convert()
         QFile rawdataFile(rawdataFilePath);
         if (!rawdataFile.open(QIODevice::WriteOnly))
         {
-            kDebug(51000) << "DNGWriter: Cannot open file to write RAW data. Aborted..." ;
+            kDebug() << "DNGWriter: Cannot open file to write RAW data. Aborted..." ;
             return -1;
         }
         QDataStream rawdataStream(&rawdataFile);
@@ -254,7 +272,7 @@ int DNGWriter::convert()
 */
         // -----------------------------------------------------------------------------------------
 
-        kDebug(51000) << "DNGWriter: Formating RAW data to memory" ;
+        kDebug() << "DNGWriter: Formating RAW data to memory" ;
 
         std::vector<unsigned short> raw_data;
         raw_data.resize(rawData.size());
@@ -269,7 +287,7 @@ int DNGWriter::convert()
 
         // -----------------------------------------------------------------------------------------
 
-        kDebug(51000) << "DNGWriter: DNG memory allocation and initialization" ;
+        kDebug() << "DNGWriter: DNG memory allocation and initialization" ;
 
         dng_memory_allocator memalloc(gDefaultDNGMemoryAllocator);
         dng_memory_stream stream(memalloc);
@@ -290,7 +308,7 @@ int DNGWriter::convert()
 
         // -----------------------------------------------------------------------------------------
 
-        kDebug(51000) << "DNGWriter: DNG IFD structure creation" ;
+        kDebug() << "DNGWriter: DNG IFD structure creation" ;
 
         dng_ifd ifd;
 
@@ -375,7 +393,7 @@ int DNGWriter::convert()
 
         // -----------------------------------------------------------------------------------------
 
-        kDebug(51000) << "DNGWriter: DNG Negative structure creation" ;
+        kDebug() << "DNGWriter: DNG Negative structure creation" ;
 
         AutoPtr<dng_negative> negative(host.Make_dng_negative());
 
@@ -450,7 +468,7 @@ int DNGWriter::convert()
         camXYZ[2][2] = identify.cameraXYZMatrix[2][0];
 
         if (camXYZ.MaxEntry() == 0.0)
-            kDebug(51000) << "DNGWriter: Warning, camera XYZ Matrix is null" ;
+            kDebug() << "DNGWriter: Warning, camera XYZ Matrix is null" ;
         else
             matrix = camXYZ;
 
@@ -470,7 +488,7 @@ int DNGWriter::convert()
 
         // -----------------------------------------------------------------------------------------
 
-        kDebug(51000) << "DNGWriter: Updating metadata to DNG Negative" ;
+        kDebug() << "DNGWriter: Updating metadata to DNG Negative" ;
 
         dng_exif *exif = negative->GetExif();
         exif->fModel.Set_ASCII(identify.model.toAscii());
@@ -628,7 +646,7 @@ int DNGWriter::convert()
             QByteArray mkrnts = meta.getExifTagData("Exif.Photo.MakerNote");
             if (!mkrnts.isEmpty())
             {
-                kDebug(51000) << "DNGWriter: Backup Makernote (" << mkrnts.size() << " bytes)" ;
+                kDebug() << "DNGWriter: Backup Makernote (" << mkrnts.size() << " bytes)" ;
 
                 dng_memory_allocator memalloc(gDefaultDNGMemoryAllocator);
                 dng_memory_stream stream(memalloc);
@@ -643,14 +661,14 @@ int DNGWriter::convert()
 
         if (d->backupOriginalRawFile)
         {
-            kDebug(51000) << "DNGWriter: Backup Original RAW file (" << inputInfo.size() << " bytes)" ;
+            kDebug() << "DNGWriter: Backup Original RAW file (" << inputInfo.size() << " bytes)" ;
 
             // Compress Raw file data to Zip archive.
 
             QTemporaryFile zipFile;
             if (!zipFile.open())
             {
-                kDebug(51000) << "DNGWriter: Cannot open temporary file to write Zip Raw file. Aborted..." ;
+                kDebug() << "DNGWriter: Cannot open temporary file to write Zip Raw file. Aborted..." ;
                 return -1;
             }
             KZip zipArchive(zipFile.fileName());
@@ -666,7 +684,7 @@ int DNGWriter::convert()
             zipRawFileData.resize(zipFileInfo.size());
             QDataStream dataStream(&zipFile);
             dataStream.readRawData(zipRawFileData.data(), zipRawFileData.size());
-            kDebug(51000) << "DNGWriter: Zipped RAW file size " << zipRawFileData.size() << " bytes" ;
+            kDebug() << "DNGWriter: Zipped RAW file size " << zipRawFileData.size() << " bytes" ;
 
             // Pass byte array to DNG sdk and compute MD5 fingerprint.
 
@@ -690,7 +708,7 @@ int DNGWriter::convert()
 
         // -----------------------------------------------------------------------------------------
 
-        kDebug(51000) << "DNGWriter: Build DNG Negative" ;
+        kDebug() << "DNGWriter: Build DNG Negative" ;
 
         // Assign Raw image data.
         negative->SetStage1Image(image);
@@ -715,7 +733,7 @@ int DNGWriter::convert()
 
         if (d->previewMode != DNGWriter::NONE)
         {
-            kDebug(51000) << "DNGWriter: DNG preview image creation" ;
+            kDebug() << "DNGWriter: DNG preview image creation" ;
 
             // Construct a preview image as TIFF format.
             AutoPtr<dng_image> tiffImage;
@@ -740,20 +758,20 @@ int DNGWriter::convert()
             QImage pre_image;
             if (!pre_image.loadFromData((uchar*)&tiff_mem_buffer.front(), tiff_mem_buffer.size(), "TIFF"))
             {
-                kDebug(51000) << "DNGWriter: Cannot load TIFF preview data in memory. Aborted..." ;
+                kDebug() << "DNGWriter: Cannot load TIFF preview data in memory. Aborted..." ;
                 return -1;
             }
 
             QTemporaryFile previewFile;
             if (!previewFile.open())
             {
-                kDebug(51000) << "DNGWriter: Cannot open temporary file to write JPEG preview. Aborted..." ;
+                kDebug() << "DNGWriter: Cannot open temporary file to write JPEG preview. Aborted..." ;
                 return -1;
             }
 
             if (!pre_image.save(previewFile.fileName(), "JPEG", 90))
             {
-                kDebug(51000) << "DNGWriter: Cannot save file to write JPEG preview. Aborted..." ;
+                kDebug() << "DNGWriter: Cannot save file to write JPEG preview. Aborted..." ;
                 return -1;
             }
 
@@ -780,7 +798,7 @@ int DNGWriter::convert()
 
         // -----------------------------------------------------------------------------------------
 
-        kDebug(51000) << "DNGWriter: DNG thumbnail creation" ;
+        kDebug() << "DNGWriter: DNG thumbnail creation" ;
 
         dng_image_preview thumbnail;
         dng_render thumbnail_render(host, *negative);
@@ -793,7 +811,7 @@ int DNGWriter::convert()
 
         // -----------------------------------------------------------------------------------------
 
-        kDebug(51000) << "DNGWriter: Creating DNG file " << outputInfo.fileName() ;
+        kDebug() << "DNGWriter: Creating DNG file " << outputInfo.fileName() ;
 
         dng_image_writer writer;
         dng_file_stream filestream(QFile::encodeName(dngFilePath), true);
@@ -803,32 +821,55 @@ int DNGWriter::convert()
                         &previewList);
 
         // -----------------------------------------------------------------------------------------
-        // Metadata makernote cleanup using Exiv2. See B.K.O #204437.
+        // Metadata makernote cleanup using Exiv2 for some RAW file types
+        // See B.K.O #204437 and #210371
 
-        kDebug(51000) << "DNGWriter: cleanup makernotes using Exiv2" ;
-
-        if (meta.load(dngFilePath))
+        if (inputInfo.suffix().toUpper() == QString("ORF"))
         {
-            meta.setWriteRawFiles(true);
-            meta.removeExifTag("Exif.OlympusIp.BlackLevel", false);
-            meta.applyChanges();
+            kDebug() << "DNGWriter: cleanup makernotes using Exiv2" ;
+
+            if (meta.load(dngFilePath))
+            {
+                meta.setWriteRawFiles(true);
+                meta.removeExifTag("Exif.OlympusIp.BlackLevel", false);
+                meta.applyChanges();
+            }
+        }
+
+        // -----------------------------------------------------------------------------------------
+        // update modification time if desired
+
+        if (d->updateFileDate)
+        {
+            QDateTime date = meta.getImageDateTime();
+
+            kDebug() << "DNGWriter: Setting modification date from meta data: " << date.toString();
+
+            // don't touch access time
+            struct stat st;
+            stat(QFile::encodeName(dngFilePath), &st);
+
+            struct utimbuf ut;
+            ut.actime  = st.st_atime;
+            ut.modtime = date.toTime_t();
+            utime(QFile::encodeName(dngFilePath), &ut);
         }
     }
 
     catch (const dng_exception &exception)
     {
         int ret = exception.ErrorCode();
-        kDebug(51000) << "DNGWriter: DNG SDK exception code (" << ret << ")" ;
+        kDebug() << "DNGWriter: DNG SDK exception code (" << ret << ")" ;
         return ret;
     }
 
     catch (...)
     {
-        kDebug(51000) << "DNGWriter: DNG SDK exception code unknow" ;
+        kDebug() << "DNGWriter: DNG SDK exception code unknow" ;
         return dng_error_unknown;
     }
 
-    kDebug(51000) << "DNGWriter: DNG conversion complete..." ;
+    kDebug() << "DNGWriter: DNG conversion complete..." ;
 
     return dng_error_none;
 }
