@@ -20,18 +20,28 @@
  *
  * ============================================================ */
 
-#include "albumdlg.h"
+// Local includes.
 
-using namespace KIPIGalleryExportPlugin;
+#include "albumdlg.h"
+#include "albumdlg.moc"
+
+namespace KIPIGalleryExportPlugin
+{
 
 AlbumDlg::AlbumDlg(QWidget *parent)
-     : QDialog(parent)
+        : QDialog(parent)
 {
     setupUi(this);
 
-    connect(buttonOk, SIGNAL(clicked()), this, SLOT(accept()));
-    connect(buttonCancel, SIGNAL(clicked()), this, SLOT(reject()));
+    connect(buttonOk, SIGNAL(clicked()), 
+            this, SLOT(accept()));
+
+    connect(buttonCancel, SIGNAL(clicked()), 
+            this, SLOT(reject()));
 }
 
 AlbumDlg:: ~AlbumDlg()
-{}
+{
+}
+
+} // namespace KIPIGalleryExportPlugin
