@@ -6,7 +6,7 @@
  * Date        : 2003-12-03
  * Description : misc utils to used in batch process
  *
- * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C) 2004-2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
@@ -58,8 +58,8 @@ public: // Static methods.
         Can't use KIO based operations as we need to use these in a thread
     */
 
-    static bool CopyFile(const QString& src, const QString& dst);
-    static bool MoveFile(const QString& src, const QString& dst);
+    static bool copyOneFile(const QString& src, const QString& dst);
+    static bool moveOneFile(const QString& src, const QString& dst);
 
     /** Thread-safe recursive dir deletion.
     */
