@@ -45,11 +45,11 @@ public:
     void setValues(const QStringList& values);
     bool getValues(QStringList& oldValues, QStringList& newValues);
 
-signals:
+Q_SIGNALS:
 
     void signalModified();
 
-private slots:
+private Q_SLOTS:
 
     void slotSelectionChanged();
     void slotAddValue();
