@@ -262,11 +262,11 @@ void Plugin_MetadataEdit::slotImportExif()
         m_lastSelectedDirectory = images.images().first().upUrl();
     }
     KUrl importEXIFFile = KFileDialog::getOpenUrl(m_lastSelectedDirectory,
-                                                  QString::null, kapp->activeWindow(),
+                                                  QString(), kapp->activeWindow(),
                                                   i18n("Select File to Import EXIF metadata") );
     if( importEXIFFile.isEmpty() )
        return;
-    
+
     m_lastSelectedDirectory = importEXIFFile.upUrl();
 
     KExiv2Iface::KExiv2 exiv2Iface;
@@ -278,7 +278,12 @@ void Plugin_MetadataEdit::slotImportExif()
         return;
     }
 
+#if KEXIV2_VERSION >= 0x010000
+    QByteArray exifData = exiv2Iface.getExifEncoded();
+#else
     QByteArray exifData = exiv2Iface.getExif();
+#endif
+
     if (exifData.isEmpty())
     {
         KMessageBox::error(kapp->activeWindow(),
@@ -429,11 +434,11 @@ void Plugin_MetadataEdit::slotImportIptc()
         m_lastSelectedDirectory = images.images().first().upUrl();
     }
     KUrl importIPTCFile = KFileDialog::getOpenUrl(m_lastSelectedDirectory,
-                                                  QString::null, kapp->activeWindow(),
+                                                  QString(), kapp->activeWindow(),
                                                   i18n("Select File to Import IPTC metadata") );
     if( importIPTCFile.isEmpty() )
        return;
-    
+
     m_lastSelectedDirectory = importIPTCFile.upUrl();
 
     KExiv2Iface::KExiv2 exiv2Iface;
@@ -596,11 +601,11 @@ void Plugin_MetadataEdit::slotImportXmp()
         m_lastSelectedDirectory = images.images().first().upUrl();
     }
     KUrl importXMPFile = KFileDialog::getOpenUrl(m_lastSelectedDirectory,
-                                                 QString::null, kapp->activeWindow(),
+                                                 QString(), kapp->activeWindow(),
                                                  i18n("Select File to Import XMP metadata") );
     if( importXMPFile.isEmpty() )
        return;
-    
+
     m_lastSelectedDirectory = importXMPFile.upUrl();
 
     KExiv2Iface::KExiv2 exiv2Iface;
@@ -792,7 +797,7 @@ void Plugin_MetadataEdit::slotRemoveComments()
         if (dlg->removeHOSTCommentIsChecked())
         {
             KIPI::ImageInfo info = m_interface->info(url);
-            info.setDescription(QString::null);
+            info.setDescription(QString());
         }
 
         KExiv2Iface::KExiv2 exiv2Iface;
