@@ -34,6 +34,7 @@
 
 // Qt includes
 
+#include <QTextDocument>
 #include <QByteArray>
 #include <QDomDocument>
 #include <QDomElement>
@@ -305,33 +306,19 @@ void PicasawebTalker::getPhotoProperty(const QString& method,const QString& argL
     //authProgressDlg->setProgress(3,4);
 }
 
-void PicasawebTalker::addPhotoTag(const QString& photoURI, const QString& tag)
+void PicasawebTalker::addPhotoTag(const QString& photoURI,
+                                  const QByteArray& metadataXML)
 {
-    //if (m_job && m_state != FE_ADDTAG)
-    //{ // we shouldn't kill the old tag request
-    //	m_job->kill();
-    //	m_job = 0;
-    //}
-
-    QString addTagXML = QString("<entry xmlns='http://www.w3.org/2005/Atom'> "
-                                "<title>%1</title> "
-                                "<category scheme='http://schemas.google.com/g/2005#kind' "
-                                "term='http://schemas.google.com/photos/2007#tag'/> "
-                                "</entry>").arg(tag);
-    QString postUrl = QString("%1").arg(photoURI);
-    QByteArray buffer;
-    buffer.append(addTagXML.toUtf8());
-
     QString auth_string = "GoogleLogin auth=" + m_token;
-    KIO::TransferJob* job = KIO::http_post(postUrl, buffer, KIO::HideProgressInfo);
+    KIO::TransferJob* job = KIO::put(photoURI, -1, KIO::HideProgressInfo);
     job->ui()->setWindow(m_parent);
     job->addMetaData("content-type", "Content-Type: application/atom+xml");
-    job->addMetaData("content-length", QString("Content-Length: %1").arg(addTagXML.length()));
+    job->addMetaData("content-length", QString("Content-Length: %1").arg(metadataXML.length()));
     job->addMetaData("customHTTPHeader", "Authorization: " + auth_string );
+    m_data_hash.insert(job, metadataXML);
 
-    //connect(job, SIGNAL(data(KIO::Job*, const QByteArray&)),
-    //        this, SLOT(data(KIO::Job*, const QByteArray&)));
-
+    connect(job, SIGNAL(dataReq(KIO::Job*, QByteArray&)),
+            this, SLOT(dataReq(KIO::Job*, QByteArray&)));
     connect(job, SIGNAL(result(KJob *)),
             this, SLOT(slotResult(KJob *)));
 
@@ -405,13 +392,11 @@ bool PicasawebTalker::addPhoto(const QString& photoPath, FPhotoInfo& info,
                                const QString& albumId, bool rescale,
                                int maxDim, int imageQuality)
 {
-    // Disabling this totally may be checking the m_state and doing selecting
-    // disabling is a better idea
-    /*if (m_job)
+    if (m_job)
     {
         m_job->kill();
         m_job = 0;
-    }*/
+    }
 
     QString album_id = albumId;
 
@@ -429,8 +414,8 @@ bool PicasawebTalker::addPhoto(const QString& photoPath, FPhotoInfo& info,
     //Create the Body in atom-xml
     QStringList body_xml;
     body_xml.append("<entry xmlns=\'http://www.w3.org/2005/Atom\'>");
-    body_xml.append("<title>"+ info.title +"</title>");
-    body_xml.append("<summary>"+ info.description +"</summary>");
+    body_xml.append("<title>"+ Qt::escape(info.title) +"</title>");
+    body_xml.append("<summary>"+ Qt::escape(info.description) +"</summary>");
     body_xml.append("<category scheme=\"http://schemas.google.com/g/2005#kind\" "
                     "term=\"http://schemas.google.com/photos/2007#photo\" />");
     body_xml.append("</entry>");
@@ -442,17 +427,29 @@ bool PicasawebTalker::addPhoto(const QString& photoPath, FPhotoInfo& info,
     // save the tags for this photo in to the tags hashmap
     tags_map.insert(info.title, info.tags);
 
-    // Check if RAW file.
-#if KDCRAW_VERSION < 0x000400
-    QString rawFilesExt(KDcrawIface::DcrawBinary::instance()->rawFiles());
-#else
-    QString rawFilesExt(KDcrawIface::KDcraw::rawFiles());
-#endif
-    QFileInfo fileInfo(photoPath);
-    bool isRAW = rawFilesExt.toUpper().contains(fileInfo.suffix().toUpper());
-
-    if (isRAW || rescale)
+    KMimeType::Ptr ptr = KMimeType::findByUrl(photoPath);
+    if(((ptr->is("image/bmp") ||
+         ptr->is("image/gif") ||
+         ptr->is("image/jpeg") ||
+         ptr->is("image/png")) &&
+        !rescale) ||
+       ptr->name().startsWith("video"))
     {
+        // use original file
+        if (!form.addFile("photo", photoPath))
+            return false;
+    }
+    else
+    {
+        // Check if RAW file.
+#if KDCRAW_VERSION < 0x000400
+        QString rawFilesExt(KDcrawIface::DcrawBinary::instance()->rawFiles());
+#else
+        QString rawFilesExt(KDcrawIface::KDcraw::rawFiles());
+#endif
+        QFileInfo fileInfo(photoPath);
+        bool isRAW = rawFilesExt.toUpper().contains(fileInfo.suffix().toUpper());
+
         // use temporary file for upload
         QImage image;
         if (isRAW)
@@ -491,12 +488,6 @@ bool PicasawebTalker::addPhoto(const QString& photoPath, FPhotoInfo& info,
 
         QFile::remove(tmpPath);
     }
-    else
-    {
-        // use original file
-        if (!form.addFile("photo", photoPath))
-            return false;
-    }
 
     form.finish();
 
@@ -555,6 +546,15 @@ void PicasawebTalker::data(KIO::Job*, const QByteArray& data)
     memcpy(m_buffer.data()+oldSize, data.data(), data.size());
 }
 
+void PicasawebTalker::dataReq(KIO::Job* job, QByteArray& data)
+{
+    if (m_data_hash.contains(job))
+    {
+        data = m_data_hash.value(job);
+        m_data_hash.remove(job);
+    }
+}
+
 void PicasawebTalker::slotCheckTokenSuccessful() 
 {
     if (authProgressDlg && !authProgressDlg->isHidden()) 
@@ -719,8 +719,6 @@ void PicasawebTalker::parseResponseGetToken(const QByteArray &data)
     {
         emit signalError(errorString);
     }
-
-    emit signalBusy(false);
 }
 
 void PicasawebTalker::getHTMLResponseCode(const QString& /*str*/)
@@ -730,10 +728,10 @@ void PicasawebTalker::getHTMLResponseCode(const QString& /*str*/)
 void PicasawebTalker::parseResponseListAlbums(const QByteArray &data)
 {
     bool success = false;
-    QString str(data);
     QDomDocument doc( "feed" );
     if ( !doc.setContent( data ) )
     {
+        emit signalGetAlbumsListFailed(i18n("Failed to fetch photo-set list"));
         return;
     }
 
@@ -823,9 +821,13 @@ void PicasawebTalker::parseResponseListPhotos(const QByteArray &data)
 void PicasawebTalker::parseResponseCreateAlbum(const QByteArray &data)
 {
     bool success = false;
-    QString errorString;
-    QString response(data);
+
     QDomDocument doc( "AddPhoto Response" );
+    if ( !doc.setContent( data ) )
+    {
+        return;
+    }
+
     // parse the new album name
     QDomElement docElem = doc.documentElement();
     QString title, photo_id, album_id, photoURI;
@@ -854,18 +856,18 @@ void PicasawebTalker::parseResponseCreateAlbum(const QByteArray &data)
         node = node.nextSibling();
     }
 
+    if(success == true)
+    {
+        listAllAlbums();
+    }
+
     // Raise a popup informing success
 }
 
-void PicasawebTalker::parseResponseAddTag(const QByteArray &data)
+void PicasawebTalker::parseResponseAddTag(const QByteArray & /*data*/)
 {
-    QString str(data);
-    remaining_tags_count -= 1;
-    emit signalBusy( false );
+    emit signalAddPhotoSucceeded();
     m_buffer.resize(0);
-
-    if (remaining_tags_count == 0)
-        emit signalAddPhotoSucceeded();
 }
 
 void PicasawebTalker::parseResponseAddPhoto(const QByteArray &data)
@@ -878,12 +880,14 @@ void PicasawebTalker::parseResponseAddPhoto(const QByteArray &data)
 
     if ( !doc.setContent( data ) )
     {
+        emit signalAddPhotoFailed(i18n("Failed to upload photo"));
         return;
     }
 
     QDomElement docElem = doc.documentElement();
-    QString title, photo_id, album_id, photoURI;
+    QString title, photoURI;
     QDomNode node = docElem.firstChild(); //this should mean <entry>
+    QDomElement keywordElem;
     QDomElement e;
 
     while( !node.isNull() )
@@ -891,18 +895,17 @@ void PicasawebTalker::parseResponseAddPhoto(const QByteArray &data)
         if ( node.isElement())
         {
             QString node_name = node.nodeName();
-            QString node_value = node.toElement().text();
+            e = node.toElement();
+            QString node_value = e.text();
             if(node_name == "title")
             {
                 success = true;
                 title = node_value;
             }
-            else if (node_name == "id")
-                photoURI = node_value;
-            else if(node_name == "gphoto:id")
-                photo_id = node_value;
-            else if(node_name == "gphoto:albumid")
-                album_id = node_value;
+            else if (node_name == "link" && e.attribute("rel") == "edit")
+                photoURI = e.attribute("href");
+            else if (node_name == "media:group")
+                keywordElem = node.firstChildElement("media:keywords");
         }
 
         node = node.nextSibling();
@@ -915,17 +918,18 @@ void PicasawebTalker::parseResponseAddPhoto(const QByteArray &data)
     else
     {
         // Update the tags information from the tags_map
-        QStringList tags     = tags_map[title];
-        remaining_tags_count = tags.count();
+        QStringList tags = tags_map[title];
 
         if (tags.count() == 0)
-            emit signalAddPhotoSucceeded();
-
-        for ( QStringList::ConstIterator it = tags.constBegin(); it != tags.constEnd(); ++it )
         {
-            QString photoURI= QString("http://picasaweb.google.com/data/feed/api/user/"
-                    "%1/albumid/%2/photoid/%3").arg(m_username).arg(album_id).arg(photo_id);
-            addPhotoTag( photoURI, *it);
+            emit signalAddPhotoSucceeded();
+        }
+        else
+        {
+            // Add our tags to the keyword element. Then send the whole XML
+            // back.
+            keywordElem.appendChild(doc.createTextNode(tags.join(", ")));
+            addPhotoTag(photoURI, doc.toString(-1).toUtf8());
         }
     }
 }
