@@ -6,7 +6,7 @@
  * Date        : 2008-01-11
  * Description : a kipi plugin to print images
  *
- * Copyright 2008-2009 by Angelo Naselli <anaselli at linux dot it>
+ * Copyright 2008-2010 by Angelo Naselli <anaselli at linux dot it>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -75,6 +75,7 @@
 #include "tphoto.h"
 #include "utils.h"
 #include "templateicon.h"
+#include "customdlg.h"
 
 namespace KIPIPrintImagesPlugin
 {
@@ -102,9 +103,12 @@ class WizardPage : public QWidget, public Ui_Class
     KPageWidgetItem* mPage;
 };
 
-const char* infoPageName=  I18N_NOOP("Select printing information");
-const char* photoPageName=  I18N_NOOP("Select page layout");
-const char* cropPageName=  I18N_NOOP("Crop photos");
+// some title name definitions (managed for translators)
+const char* infoPageName  =  I18N_NOOP("Select printing information");
+const char* photoPageName =  I18N_NOOP("Select page layout");
+const char* cropPageName  =  I18N_NOOP("Crop photos");
+// custom page layout
+const char* customPageLayoutName = I18N_NOOP("Custom");
 
 typedef WizardPage<Ui_InfoPage>  InfoPage;
 typedef WizardPage<Ui_PhotoPage> PhotoPage;
@@ -125,6 +129,7 @@ struct Wizard::Private
 
   KIPIPlugins::KPAboutData* mAbout;
 
+  // Page Size in mm
   QSizeF             m_pageSize;
   QList<TPhoto*>     m_photos;
   QList<TPhotoSize*> m_photoSizes;
@@ -468,12 +473,7 @@ void Wizard::parseTemplateFile( QString fn, QSizeF pageSize )
           continue;
         }
 
-        // Next templates are good we restore size to its unit
-//           if (unit != "mm")
-//           {
-//             size = QSizeF(e.attribute("width", "0").toFloat(), e.attribute("height", "0").toFloat());
-//           }
-
+        // Next templates are good
         kDebug() << "layout size " << size << " page size " << pageSize;
 
         QDomNode np = e.firstChild();
@@ -491,18 +491,14 @@ void Wizard::parseTemplateFile( QString fn, QSizeF pageSize )
               if (pageSize == QSizeF(0,0))
               {
                 sizeManaged = size * scaleValue;
-                //p->layouts.append ( new QRect ( 0, 0, size.width()*scaleValue, size.height()*scaleValue ) );
               }
               else if (unit == "inches" || unit == "inch")
               {
                 sizeManaged = pageSize * scaleValue / 25.4;
-//                   p->layouts.append ( new QRect ( 0, 0, (pageSize.width()*scaleValue/25.4),
-//                                                   (pageSize.height()*scaleValue/25.4) ) );
               }
               else
               {
                 sizeManaged = pageSize * 10;
-//                   p->layouts.append ( new QRect ( 0, 0, pageSize.width()*10, pageSize.height()*10 ) );
               }
               
               p->layouts.append ( new QRect ( 0, 0, (int)sizeManaged.width(), (int)sizeManaged.height() ) );
@@ -522,7 +518,7 @@ void Wizard::parseTemplateFile( QString fn, QSizeF pageSize )
                 p->label = KDesktopFile(*it).readName();
               else
               {
-                p->label = ep.attribute("name","XXX");  // FIXME i18n()
+                p->label = ep.attribute("name","XXX");
                 kWarning() << "missed template tranlation " << desktopFileName;
               }
               p->dpi = ep.attribute("dpi","0").toInt();
@@ -658,11 +654,23 @@ void Wizard::initPhotoSizes ( QSizeF pageSize )
       d->mPhotoPage->ListPhotoSizes->addItem ( pWItem );
     }
   }
+  // Adding custom choice
+  QListWidgetItem *pWItem = new QListWidgetItem ( i18n(customPageLayoutName) );
+  
+  //TODO FREE STYLE ICON 
+  TemplateIcon ti(80, pageSize.toSize());
+  ti.begin();
+  QPainter& painter = ti.getPainter();
+  painter.setPen( Qt::color1 );
+  painter.drawText(painter.viewport(), Qt::AlignCenter, i18n("Free"));
+  ti.end();
+
+  pWItem->setIcon( ti.getIcon());
+  d->mPhotoPage->ListPhotoSizes->addItem ( pWItem );
+  // 
   d->mPhotoPage->ListPhotoSizes->blockSignals ( false );
 
   d->mPhotoPage->ListPhotoSizes->setCurrentRow ( 0, QItemSelectionModel::Select );
-
-//   d->mPhotoPage->ListPhotoSizes->setCurrentItem(0);
 }
 
 double getMaxDPI ( QList<TPhoto*> photos, QList<QRect*> layouts, /*unsigned*/ int current )
@@ -745,7 +753,7 @@ void Wizard::printCaption ( QPainter &p, TPhoto* photo, int captionW, int captio
     //TODO fix length, maybe useless
     int captionLineLocalLength = 40;
 
-    for ( currIndex = captionIndex; currIndex < caption.length() && !breakLine; currIndex++ )
+    for ( currIndex = captionIndex; currIndex < caption.length() && !breakLine; ++currIndex )
       if ( caption[currIndex] == QChar ( '\n' ) || caption[currIndex].isSpace() )
         breakLine = true;
 
@@ -757,7 +765,7 @@ void Wizard::printCaption ( QPainter &p, TPhoto* photo, int captionW, int captio
     for ( currIndex = captionIndex;
             currIndex <= captionIndex + captionLineLocalLength &&
             currIndex < caption.length() && !breakLine;
-            currIndex++ )
+            ++currIndex )
     {
       breakLine = ( caption[currIndex] == QChar ( '\n' ) ) ? true : false;
 
@@ -770,7 +778,7 @@ void Wizard::printCaption ( QPainter &p, TPhoto* photo, int captionW, int captio
     captionIndex = currIndex; // The line is ended
 
     if ( captionIndex != caption.length() )
-      while ( !newLine.endsWith ( " " ) )
+      while ( !newLine.endsWith ( ' ' ) )
       {
         newLine.truncate ( newLine.length() - 1 );
         captionIndex--;
@@ -793,7 +801,7 @@ void Wizard::printCaption ( QPainter &p, TPhoto* photo, int captionW, int captio
 
   // Now draw the caption
   // TODO allow printing captions  per photo and on top, bottom and vertically
-  for ( int lineNumber = 0; lineNumber < ( int ) captionByLines.count(); lineNumber++ )
+  for ( int lineNumber = 0; lineNumber < ( int ) captionByLines.count(); ++lineNumber )
   {
     if ( lineNumber > 0 )
       p.translate ( 0, - ( int ) ( pixelsHigh ) );
@@ -1421,11 +1429,18 @@ void  Wizard::pageChanged ( KPageWidgetItem *current, KPageWidgetItem *before )
     // PhotoPage
     initPhotoSizes ( d->m_printer->paperSize(QPrinter::Millimeter) );
     // restore photoSize 
-    QList<QListWidgetItem *> list = d->mPhotoPage->ListPhotoSizes->findItems ( d->m_savedPhotoSize, Qt::MatchExactly );
-    if ( list.count() )
-      d->mPhotoPage->ListPhotoSizes->setCurrentItem ( list[0] );
-    else
+    if (d->m_savedPhotoSize == i18n(customPageLayoutName))
+    {
       d->mPhotoPage->ListPhotoSizes->setCurrentRow ( 0 );
+    }
+    else
+    {
+      QList<QListWidgetItem *> list = d->mPhotoPage->ListPhotoSizes->findItems ( d->m_savedPhotoSize, Qt::MatchExactly );
+      if ( list.count() )
+        d->mPhotoPage->ListPhotoSizes->setCurrentItem ( list[0] );
+      else
+        d->mPhotoPage->ListPhotoSizes->setCurrentRow ( 0 );
+    }
     // create our photo sizes list
     previewPhotos();
   }
@@ -1663,7 +1678,170 @@ void Wizard::ListPrintOrder_selected()
 
 void Wizard::ListPhotoSizes_selected()
 {
+  TPhotoSize *s = NULL;
+  int scaleValue;
+  QSizeF size, sizeManaged;
+
+  // TODO FREE STYLE
+  // check if layout is managed by templates or free one
+  // get the selected layout
+  int curr = d->mPhotoPage->ListPhotoSizes->currentRow();
+  QListWidgetItem * item = d->mPhotoPage->ListPhotoSizes->item(curr);
+  // if custom page layout we launch a dialog to choose what kind
+  if ( item->text() == i18n ( customPageLayoutName ) )
+  {
+    // check if a custom layout has already been added
+    if (curr >= 0 && curr < d->m_photoSizes.size())
+    {
+      s = d->m_photoSizes.at ( curr );
+      d->m_photoSizes.removeAt ( curr );
+      delete s;
+      s = NULL;
+    }
+    CustomLayoutDlg custDlg(this);
+    custDlg.readSettings();
+    custDlg.exec();
+    custDlg.saveSettings();
+    
+    // get parameters from dialog
+    size = d->m_pageSize;
+    scaleValue = 10; // 0.1 mm
+    
+    // convert to mm
+    if (custDlg.m_photoUnits->currentText() == i18n("inches"))
+    {
+      size /= 25.4;
+      scaleValue = 1000;
+    }
+    else if (custDlg.m_photoUnits->currentText() == i18n("cm"))
+    {
+      size /= 10;
+      scaleValue = 100;
+    }
+    sizeManaged = size * scaleValue;
+
+    s = new TPhotoSize;
+    TemplateIcon iconpreview( 80, sizeManaged.toSize() );
+    iconpreview.begin();
+    if (custDlg.m_photoGridCheck->isChecked())
+    {
+      // custom photo grid
+      int rows       = custDlg.m_gridRows->value();
+      int columns    = custDlg.m_gridColumns->value();
+ 
+      s->layouts.append ( new QRect ( 0, 0, (int)sizeManaged.width(), (int)sizeManaged.height() ) );
+      s->autoRotate = custDlg.m_autorotate->isChecked();
+      s->label      = item->text();
+      s->dpi        = 0;
+      
+      int pageWidth  = (int)(size.width())*scaleValue;
+      int pageHeight = (int)(size.height())*scaleValue;
+      createPhotoGrid(s, pageWidth,
+                      pageHeight,
+                      rows,
+                      columns,
+                      &iconpreview);
+    }
+    else if (custDlg.m_fitAsManyCheck->isChecked())
+    {
+      int width       = custDlg.m_photoWidth->value();
+      int height      = custDlg.m_photoHeight->value();
+
+      //photo size must be less than page size
+      static const float round_value = 0.01F;
+      if ((height > (size.height() +round_value) ||
+           width  > (size.width() +round_value)))
+      {
+        kDebug() << "photo size " << QSize(width,height) << "> page size " << size;
+        delete s;
+        s = NULL;
+      }
+      else
+      {
+        // fit as many photos of given size as possible
+        s->layouts.append ( new QRect ( 0, 0, (int)sizeManaged.width(), (int)sizeManaged.height() ) );
+        s->autoRotate = custDlg.m_autorotate->isChecked();
+        s->label      = item->text();
+        s->dpi        = 0;
+
+
+        int nColumns    = int(size.width()  / width);
+        int nRows       = int(size.height() / height);
+        int spareWidth  = int(size.width())  % width;
+        // check if there's no room left to separate photos
+        if (nColumns > 1 &&  spareWidth == 0)
+        {
+            nColumns -= 1;
+            spareWidth = width;
+        }
+        int spareHeight = int(size.height()) % height;
+        
+        // check if there's no room left to separate photos
+        if (nRows > 1 && spareHeight == 0)
+        {
+            nRows -= 1;
+            spareHeight = height;
+        }
+        if (nRows >0 && nColumns >0)
+        {
+          // n photos => dx1, photo1, dx2, photo2,... photoN, dxN+1
+          int dx = spareWidth * scaleValue / (nColumns+1);
+          int dy = spareHeight * scaleValue / (nRows+1);
+          int photoX = 0;
+          int photoY = 0;
+          width  *= scaleValue;
+          height *= scaleValue;
+          for (int row=0; row<nRows; ++row)
+          {
+            photoY = dy*(row+1) + (row*height);
+            for (int col=0; col < nColumns; ++col)
+            {
+              photoX = dx*(col+1) +(col*width);
+              kDebug() << "photo at P(" << photoX << ", " << photoY << ") size(" << width << ", " << height;
+
+              s->layouts.append(new QRect(photoX,photoY,
+                                          width, height));
+              iconpreview.fillRect( photoX, photoY, width, height, Qt::color1 );
+            }
+          }
+        }
+        else
+        {
+          kDebug() << "I can't go on, rows " << nRows << "> columns " << nColumns;
+          delete s;
+          s = NULL;
+
+        }
+      }
+    }
+    else
+    {
+      // Atckin's layout
+    }
+    // TODO not for Atckin's layout
+    iconpreview.end();
+    if (s)
+    {
+      s->icon = iconpreview.getIcon();
+      d->m_photoSizes.append ( s );
+    }
+  }
+  else
+  {
+    s = d->m_photoSizes.at ( curr );
+  }
+      
+  
+  if (!s)
+  {
+    // change position to top
+    d->mPhotoPage->ListPhotoSizes->blockSignals ( true);
+    d->mPhotoPage->ListPhotoSizes->setCurrentRow ( 0, QItemSelectionModel::Select );
+    d->mPhotoPage->ListPhotoSizes->blockSignals ( false );
+  }
+  
   previewPhotos();
+  
 }
 
 void Wizard::BtnPrintOrderDown_clicked()
@@ -2060,7 +2238,7 @@ void Wizard::accept()
       return;
     }
     if ( path.right ( 1 ) != "/" )
-      path = path + "/";
+      path = path + '/';
     path = path + "kipi_printassistant_";
     kDebug() << path;
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
