@@ -6,7 +6,7 @@
  * Date        : 2003-10-24
  * Description : Raw converter batch dialog
  *
- * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -90,7 +90,7 @@ private Q_SLOTS:
     void slotSaveFormatChanged();
     void slotConvertBlinkTimerDone();
 
-    void slotAction(const ActionData&);
+    void slotAction(const KIPIRawConverterPlugin::ActionData&);
 
     void slotThumbnail(const KUrl&, const QPixmap&);
 
