@@ -5,10 +5,10 @@
  *
  * Date        : 2008-12-01
  * Description : a kipi plugin to import/export images to/from 
-                 SmugMug web service
+ *               SmugMug web service
  *
  * Copyright (C) 2005-2008 by Vardhman Jain <vardhman at gmail dot com>
- * Copyright (C) 2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2008-2009 by Luka Renko <lure at kubuntu dot org>
  *
  * This program is free software; you can redistribute it
@@ -27,12 +27,14 @@
 #include "plugin_smug.moc"
 
 // C ANSI includes
+
 extern "C"
 {
 #include <unistd.h>
 }
 
 // KDE includes
+
 #include <KDebug>
 #include <KConfig>
 #include <KApplication>
@@ -41,22 +43,26 @@ extern "C"
 #include <KGenericFactory>
 #include <KLibLoader>
 #include <KStandardDirs>
+#include <kwindowsystem.h>
 
 // LibKIPI includes
+
 #include <libkipi/interface.h>
 
 // Local includes
+
 #include "smugwindow.h"
 
 K_PLUGIN_FACTORY( SmugFactory, registerPlugin<Plugin_Smug>(); )
 K_EXPORT_PLUGIN ( SmugFactory("kipiplugin_smug") )
 
-Plugin_Smug::Plugin_Smug(QObject *parent,
-                                     const QVariantList &/*args*/)
-                   : KIPI::Plugin(SmugFactory::componentData(),
-                                  parent, "Smug")
+Plugin_Smug::Plugin_Smug(QObject *parent, const QVariantList& /*args*/)
+           : KIPI::Plugin(SmugFactory::componentData(), parent, "Smug")
 {
-    kDebug(51001) << "Plugin_Smug plugin loaded";
+    m_dlgImport = 0;
+    m_dlgExport = 0;
+
+    kDebug(AREA_CODE_LOADING) << "Plugin_Smug plugin loaded";
 }
 
 void Plugin_Smug::setup(QWidget* widget)
@@ -68,7 +74,7 @@ void Plugin_Smug::setup(QWidget* widget)
     m_actionExport = actionCollection()->addAction("smugexport");
     m_actionExport->setText(i18n("Export to &SmugMug..."));
     m_actionExport->setIcon(KIcon("smugmug"));
-    m_actionExport->setShortcut(Qt::ALT+Qt::SHIFT+Qt::Key_S);
+    m_actionExport->setShortcut(KShortcut(Qt::ALT+Qt::SHIFT+Qt::Key_S));
 
     connect(m_actionExport, SIGNAL( triggered(bool) ),
             this, SLOT( slotExport()) );
@@ -78,7 +84,7 @@ void Plugin_Smug::setup(QWidget* widget)
     m_actionImport = actionCollection()->addAction("smugimport");
     m_actionImport->setText(i18n("Import from &SmugMug..."));
     m_actionImport->setIcon(KIcon("smugmug"));
-    m_actionImport->setShortcut(Qt::ALT+Qt::SHIFT+Qt::CTRL+Qt::Key_S);
+    m_actionImport->setShortcut(KShortcut(Qt::ALT+Qt::SHIFT+Qt::CTRL+Qt::Key_S));
 
     connect(m_actionImport, SIGNAL( triggered(bool) ),
             this, SLOT( slotImport()) );
@@ -88,7 +94,7 @@ void Plugin_Smug::setup(QWidget* widget)
     KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>(parent());
     if (!interface)
     {
-        kError(51000) << "Kipi interface is null!";
+        kError() << "Kipi interface is null!";
         m_actionImport->setEnabled(false);
         m_actionExport->setEnabled(false);
         return;
@@ -107,18 +113,27 @@ void Plugin_Smug::slotExport()
     KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>(parent());
     if (!interface)
     {
-        kError(51000) << "Kipi interface is null!";
+        kError() << "Kipi interface is null!";
         return;
     }
 
     KStandardDirs dir;
-    QString tmp = dir.saveLocation("tmp", "kipi-smug-"
-                                           + QString::number(getpid()) + '/');
+    QString tmp = dir.saveLocation("tmp", QString("kipi-smug-") + QString::number(getpid()) + QString("/"));
 
-    // We clean it up in the close button
-    m_dlg = new KIPISmugPlugin::SmugWindow(interface, tmp, false,
-                                           kapp->activeWindow());
-    m_dlg->show();
+    if (!m_dlgExport)
+    {
+        // We clean it up in the close button
+        m_dlgExport = new KIPISmugPlugin::SmugWindow(interface, tmp, false, kapp->activeWindow());
+    }
+    else
+    {
+        if (m_dlgExport->isMinimized())
+            KWindowSystem::unminimizeWindow(m_dlgExport->winId());
+
+        KWindowSystem::activateWindow(m_dlgExport->winId());
+    }
+
+    m_dlgExport->reactivate();
 }
 
 void Plugin_Smug::slotImport()
@@ -126,18 +141,27 @@ void Plugin_Smug::slotImport()
     KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>(parent());
     if (!interface)
     {
-        kError(51000) << "Kipi interface is null!";
+        kError() << "Kipi interface is null!";
         return;
     }
 
     KStandardDirs dir;
-    QString tmp = dir.saveLocation("tmp", "kipi-smug-"
-                                           + QString::number(getpid()) + '/');
+    QString tmp = dir.saveLocation("tmp", QString("kipi-smug-") + QString::number(getpid()) + QString("/"));
 
-    // We clean it up in the close button
-    m_dlg = new KIPISmugPlugin::SmugWindow(interface, tmp, true,
-                                           kapp->activeWindow());
-    m_dlg->show();
+    if (!m_dlgImport)
+    {
+        // We clean it up in the close button
+        m_dlgImport = new KIPISmugPlugin::SmugWindow(interface, tmp, true, kapp->activeWindow());
+    }
+    else
+    {
+        if (m_dlgImport->isMinimized())
+            KWindowSystem::unminimizeWindow(m_dlgImport->winId());
+
+        KWindowSystem::activateWindow(m_dlgImport->winId());
+    }
+
+    m_dlgImport->show();
 }
 
 KIPI::Category Plugin_Smug::category( KAction* action ) const
@@ -147,6 +171,6 @@ KIPI::Category Plugin_Smug::category( KAction* action ) const
     else if (action == m_actionImport)
         return KIPI::ImportPlugin;
 
-    kWarning(51000) << "Unrecognized action for plugin category identification";
+    kWarning() << "Unrecognized action for plugin category identification";
     return KIPI::ExportPlugin;
 }
